# Quizzical ChangeLog

## v0.2.0

**Released: 2024-11-24**

- Fixed a crash on startup caused by no longer needing a workaround for a
  Textual bug.
- Overhaul of the colours to handle the fact that Textual seems to do
  colouring differently now.

## v0.1.0

**Released: 2024-01-29**

- Initial release.

[//]: # (ChangeLog.md ends here)
